@@ -23,9 +23,8 @@ class KeyCache::RefreshKeysJob : public QObject
 {
     Q_OBJECT
 public:
-
     explicit RefreshKeysJob(KeyCache *cache, QObject *parent = nullptr);
-    ~RefreshKeysJob();
+    ~RefreshKeysJob() override;
 
     void start();
     void cancel();
@@ -37,8 +36,7 @@ Q_SIGNALS:
 private:
     class Private;
     friend class Private;
-    Private * const d;
+    Private *const d;
     Q_PRIVATE_SLOT(d, void listAllKeysJobDone(GpgME::KeyListResult, std::vector<GpgME::Key>))
 };
 }
-
